pub struct TerminalTable<O: Write + IsTerminal> {
pub opts: TerminalTableOpts,
/* private fields */
}Expand description
Capable of streaming, which requires defining the column widths beforehand. If a value is wider than the defined column width for that value, a single space is still printed between the value and the next. The last column does not need a width, and no padding is printed.
Fields
opts: TerminalTableOptsImplementations
Sourceimpl<O: Write + IsTerminal> TerminalTable<O>
impl<O: Write + IsTerminal> TerminalTable<O>
Sourcepub fn new(widths: &[usize], opts: TerminalTableOpts, out: O) -> Self
pub fn new(widths: &[usize], opts: TerminalTableOpts, out: O) -> Self
The length of widths must be one less than that of titles
(the last column does not need a width). Appends a space to
each title (or generally, formatted item), to make sure italic
text is not clipped on terminals. That will be fine as you’ll
want your widths to be at least 1 longer than the text itself,
anyway. widths must include the spacing between the
columns–i.e. make it 2-3 larger than the max. expected width
of the data.